@@ -1,7 +1,5 @@
 # standar library
 import asyncio
-import functools
-from asyncio import shield
 
 # contrib
 from networktools.library import my_random_string
@@ -20,7 +18,10 @@ class TaskScheduler:
     an id
 
     :param args: an unpacked list
-    :param kwargs: an unpacked dictionary with at least {*ipt* dict, *ico* dict, *assigned_task* dict, *nproc* int, *sta_init* dict}, all in shared memory manager
+    :param kwargs: an unpacked dictionary with at least
+    {*ipt* dict, *ico* dict, *assigned_task* dict, *nproc* int, *sta_init*
+    dict},
+    all in shared memory manager
 
     """
 
@@ -83,15 +84,19 @@ class TaskScheduler:
 
     def set_new_run_task(self, **coros_callback):
         """
-        Is a function that you have to call to define the corutines which you need
+        Is a function that you have to call to define the corutines which you
+        need
         to execute on the wheel (gear)
 
-        Is recomended the use at the end of the __init__ method on your new class.
+        Is recomended the use at the end of the __init__ method on your new
+        class.
 
-        :param coros_callback: is a dictionary with the corutines, that depends of what you need:
+        :param coros_callback: is a dictionary with the corutines, that depends
+        of what you need:
 
         - A unidirectional machine: you have to set only the *run_task* key
-        - A bidirectional machine: you ahve to set also *net2service* and *service2net* keys
+        - A bidirectional machine: you ahve to set also *net2service* and
+        *service2net* keys
         """
         run_task = coros_callback.get('run_task', None)
         net2service_task = coros_callback.get('net2service', {})
@@ -349,7 +354,8 @@ class TaskScheduler:
                     tasks.append(task_2)
             except Exception as ex:
                 print(
-                    "Error en collect_task, gather stations, net2service(task) %s, error %s"
+                    "Error en collect_task, gather stations" +
+                    ", net2service(task) %s, error %s"
                     % (ipt, ex))
                 print(ex)
                 raise ex
@@ -369,7 +375,8 @@ class TaskScheduler:
                     tasks.append(task_3)
             except Exception as exe:
                 print(
-                    "Error en collect_task, gather stations, service2net(task) %s, error %s"
+                    "Error en collect_task, gather stations, " +
+                    "service2net(task) %s, error %s"
                     % (ipt, exe))
                 print(exe)
                 raise exe
@@ -390,7 +397,5 @@ class TaskScheduler:
             print("Error en collect_task, manager %s, error %s" % (ipt, exe))
             print(exe)
             raise exe
-        bprint("Loop is running yet? IPT->%s" % ipt)
-        rprint(loop.is_running())
         if not loop.is_running():
             loop.run_forever()
