@@ -2,7 +2,7 @@ import asyncio
 import functools
 import sys
 
-VERSION=sys.version_info
+VERSION = sys.version_info
 
 # every coroutine
 async def pause(sleep, *args, **kwargs):
@@ -17,7 +17,8 @@ async def coromask(coro, args, kwargs, fargs):
 
     :param coro: is a coroutine object defined by the developer
     :param args: the list of arguments to run on the corotine *coro*
-    :param fargs: the function that process the input and create an output related with the coro result
+    :param fargs: the function that process the input and create an output
+    related with the coro result
 
     :returns: a result, is a list of the elements for future argument
     """
@@ -83,7 +84,8 @@ def simple_fargs(_in, obtained):
     Return _in
 
     :_in: the input list
-    :param obtained: the object that came from the result of coroutine execution
+    :param obtained: the object that came from the result of coroutine
+    execution
 
     :returns: _in
     """
@@ -97,7 +99,8 @@ def simple_fargs_out(_in, obtained):
     Return obtained
 
     :param _in: the input list
-    :param obtained: the object that came from the result of coroutine execution
+    :param obtained: the object that came from the result of coroutine
+    execution
 
     :returns: obtained
     """
@@ -176,8 +179,7 @@ class TaskLoop:
         self._name = name
 
     def create(self):
-        print(VERSION)
-        if VERSION.major==3 and VERSION.minor>=8:
+        if VERSION.major == 3 and VERSION.minor >= 8:
             task = self.loop.create_task(
                 coromask(
                     self.coro,
@@ -187,7 +189,7 @@ class TaskLoop:
             task.add_done_callback(
                  functools.partial(self.renew, task, self.coro, self.fargs))
             return task
-        if VERSION.major==3 and VERSION.minor==7:
+        if VERSION.major == 3 and VERSION.minor == 7:
             task = self.loop.create_task(
                 coromask(
                     self.coro,
@@ -224,11 +226,11 @@ class TaskLoop:
                     if self.control == 'CONTINUE':
                         coro = self.coro
                     task = None
-                    if VERSION.major==3 and VERSION.minor>=8:
+                    if VERSION.major == 3 and VERSION.minor >= 8:
                         task = loop.create_task(
                             coromask(coro, result_args,
                                      result_kwargs, fargs))
-                    if VERSION.major==3 and VERSION.minor>=7:
+                    if VERSION.major == 3 and VERSION.minor == 7:
                         task = loop.create_task(
                             coromask(coro, result_args,
                                      result_kwargs, fargs))
@@ -238,11 +240,11 @@ class TaskLoop:
                     pause_args = [self.time_pause]
                     pause_kwargs = {}
                     task = None
-                    if VERSION.major==3 and VERSION.minor>=8:
+                    if VERSION.major == 3 and VERSION.minor >= 8:
                         task = loop.create_task(
                             coromask(pause, pause_args,
                                      pause_kwargs, fargs))
-                    if VERSION.major==3 and VERSION.minor>=7:
+                    if VERSION.major == 3 and VERSION.minor == 7:
                         task = loop.create_task(
                             coromask(pause, pause_args,
                                      pause_kwargs, fargs))
@@ -265,12 +267,11 @@ class TaskLoop:
                     coro {coro},
                     fargs {fargs}"""
                 if task.done():
-                    msg_done = f"TaskLoop, exception, Task done {task.result()}"
+                    msg_done = f"TaskLoop exception, Task done {task}"
                     if log:
                         log.exception(msg_done)
                 if log:
                     log.exception(msg)
-                print("TaskLoop. Excepcion en renew", e)
                 raise e
         else:
             try:
